package com.fs.store.service;

import java.util.List;

import com.fs.common.core.domain.R;
import com.fs.store.domain.FsStoreOrderOffline;
import com.fs.store.param.FsStoreOrderOfflineCreateParam;
import com.fs.store.param.FsStoreOrderOfflineParam;
import com.fs.store.vo.FsStoreOrderOfflineListVO;

/**
 * 线下订单Service接口
 *
 * @author fs
 * @date 2024-10-29
 */
public interface IFsStoreOrderOfflineService
{
    /**
     * 查询线下订单
     *
     * @param orderId 线下订单ID
     * @return 线下订单
     */
    public FsStoreOrderOffline selectFsStoreOrderOfflineById(Long orderId);

    /**
     * 查询线下订单列表
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 线下订单集合
     */
    public List<FsStoreOrderOffline> selectFsStoreOrderOfflineList(FsStoreOrderOffline fsStoreOrderOffline);

    /**
     * 新增线下订单
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 结果
     */
    public int insertFsStoreOrderOffline(FsStoreOrderOffline fsStoreOrderOffline);

    /**
     * 修改线下订单
     *
     * @param fsStoreOrderOffline 线下订单
     * @return 结果
     */
    public int updateFsStoreOrderOffline(FsStoreOrderOffline fsStoreOrderOffline);

    /**
     * 批量删除线下订单
     *
     * @param orderIds 需要删除的线下订单ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineByIds(Long[] orderIds);

    /**
     * 删除线下订单信息
     *
     * @param orderId 线下订单ID
     * @return 结果
     */
    public int deleteFsStoreOrderOfflineById(Long orderId);


    List<FsStoreOrderOfflineListVO> selectFsStoreOrderOfflineListVO(FsStoreOrderOfflineParam param);

    R createOrder(FsStoreOrderOfflineCreateParam param);

    FsStoreOrderOfflineListVO selectFsStoreOrderOfflineVOById(Long orderId);

    int uploadCredentials(FsStoreOrderOffline order);
}
